# Generated by Django 3.2.12 on 2022-06-14 12:46

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='ConteudoCustom',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('local', models.CharField(choices=[('Nenhum Local', 'Nenhum Local'), ('Head - Admin', 'Head - Admin'), ('Style - Admin', 'Style - Admin'), ('Script - Admin', 'Script - Admin')], default='Nenhum Local', max_length=100, verbose_name='')),
                ('conteudo', models.TextField(null=True, verbose_name='Conteúdo')),
            ],
            options={
                'verbose_name': 'Conteúdo Customizado',
                'verbose_name_plural': 'Conteúdos Customizados',
            },
        ),
    ]
