# Generated by Django 3.2.12 on 2022-06-28 19:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_app_novadata', '0002_conteudocustom_logo'),
    ]

    operations = [
        migrations.AlterField(
            model_name='conteudocustom',
            name='local',
            field=models.CharField(choices=[('Nenhum Local', 'Nenhum Local'), ('Head - Admin', 'Head - Admin'), ('Style - Admin', 'Style - Admin'), ('Script - Admin', 'Script - Admin'), ('Logo - Admin', 'Logo - Admin')], default='Nenhum Local', max_length=100, verbose_name=''),
        ),
    ]
