# Generated by Django 3.2.12 on 2022-06-28 19:38

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_app_novadata', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='conteudocustom',
            name='logo',
            field=models.FileField(null=True, upload_to='admin/logo/', verbose_name='Logo'),
        ),
    ]
